==> vtigercrm-5.2.1.tgz: modules/Services/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/

$mod_strings = Array(
'Services'=>'Servicios',
'SINGLE_Services'=>'Servicio',
'LBL_LIST_SERVICE_NAME'=>'Nombre Servicio',
'LBL_TOOL_FORM_TITLE'=>'Herramientas Servicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Servicio',
'LBL_SERVICE_NAME'=>'Nombre Servicio:',
'LBL_PRICEBOOK_NAME'=>'Nombre Tarifa:',
'LBL_PRICEBOOK'=>'Tarifa:',
'LBL_PRICEBOOK_INFORMATION'=>'Información Tarifa:',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción:',
'LBL_PRICING_INFORMATION'=>'Información Precios:',
'LBL_LIST_FORM_TITLE'=>'Lista Servicios',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Lista Tarifas',
'LBL_LIST_CATEGORY'=>'Categoría Servicio',
'LBL_CATEGORY'=>'Categoría Servicio:',
'LBL_SERVICE_ACTIVE'=>'Servicio Activo',
'LBL_SERVICE_COMMISSION_RATE'=>'Comisión',
'LBL_SERVICE_QTY_PER_UNIT'=>'Unidades',
'LBL_SERVICE_UNIT_PRICE'=>'Precio unitario',
'LBL_PB_LIST_PRICE'=>'Precio lista',
'LBL_SERVICE_DESCRIPTION'=>'Descripción',
'LBL_NEW_FORM_TITLE'=>'Nuevo Servicio',
'LBL_SERVICE_INFORMATION'=>'Información Servicio',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción',

'LBL_SERVICE'=>'Servicio',
'LBL_NEW_SERVICE'=>'Nuevo Servicio',
'LBL_COLON'=>':',

'LBL_DESCRIPTION'=>'Descripción',

'LBL_NEW_CALL'=>'Nueva llamada',
'LBL_CALL_TITLE'=>'Llamadas',

'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',

'LBL_SERVICECATEGORY'=>'Categoría Servicio',
'Service Category'=>'Categoría Servicio',
'LBL_SUPPORT_START_DATE'=>'Fecha inicio soporte',
'LBL_SUPPORT_EXPIRY_DATE'=>'Fecha fin soporte',

'Commission Rate'=>'Comisión (%)',
'Unit Price'=>'Precio unitario',
'Price'=>'Precio',
'No of Units' => 'Número unidades',
'Service No' => 'Número Servicio',
'Service Active' => 'Servicio Activo',
'Owner' => 'Propietario',
'Support Start Date'=>'Fecha inicio soporte',
'Support Expiry Date'=>'Fecha fin soporte',
'Sales Start Date'=>'Fecha inicio venta',
'Sales End Date'=>'Fecha fin venta',
'Created Time'=>'Fecha creación',
'Modified Time'=>'Fecha modificación',
'Related To'=>'Relacionado con',
'Usage Unit'=>'Unidades de consumo',
'Currency'=>'Moneda',
'Tax Class'=>'Tipo impuesto',

//Mapping for Name
'Name'=>'Nombre',
'Company Name'=>'Nombre empresa',
'Phone'=>'Teléfono',
'Email'=>'Email',
'Website'=>'Página Web',
'Category'=>'Categoría',
'Street'=>'Dirección',
'City'=>'Población',
'State'=>'Provincia',
'Postal Code'=>'Código Postal',
'Country'=>'País',
'Description'=>'Descripción',
'Po Box'=>'Apdo. Correos',

//Mapping for price book
'Price Book Name'=>'Nombre Tarifa',
'Service Name'=>'Nombre Servicio',
'Active'=>'Activo',

'LBL_ALL'=>'Todos',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'Buscar Tarifa',
'LBL_PRICEBOOK_TITLE'=>'Tarifas',
'LBL_SERVICES_TITLE'=>'Servicios',
'LBL_COMPANY_NAME'=>'Nombre empresa',
'LBL_CATEGORY_TITLE'=>'Categoría',
'LBL_ACTIVE_TITLE'=>'Activo',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Añadir a Tarifas [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Añadir a Tarifas',
'LBL_ADD_SERVICE_PRICEBOOKS'=>'Añadir Servicio a Tarifas',
'LBL_ADD_SERVICES_PRICEBOOK'=>'Añadir Servicios a Tarifa',
'LBL_SERVICE_PRICES'=>'Precios Servicio',
'Services'=>'Servicios',

// Picklist
'--None--' => '--Ninguno--',
'Installation' => 'Instalación',
'Migration' => 'Migración',
'Customization' => 'Personalización',
'Training' => 'Formación',
'Hours'=>'Horas',
'Days'=>'Días',
'Incidents'=>'Incidentes',

'LBL_NO_TAXES_ASSOCIATED'=>'No hay impuestos asociados a este servicio',

);

?>

==> vtigercrm-5.4.0.tgz: modules/Services/language/es_es.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * 
 *  ********************************************************************************
 *  Module       : Services
 *  Language     : Español
 *  Version      : 5.4.0 
 *  Last change  : 2012-02-27
 *  Author       : Joe Bordes JPL TSolucio, S.L.
 ************************************************************************************/

$mod_strings = Array(
'Services'=>'Servicios',
'SINGLE_Services'=>'Servicio',
'LBL_LIST_SERVICE_NAME'=>'Nombre Servicio',
'LBL_TOOL_FORM_TITLE'=>'Herramientas Servicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Servicio',
'LBL_SERVICE_NAME'=>'Nombre Servicio:',
'LBL_PRICEBOOK_NAME'=>'Nombre Tarifa:',
'LBL_PRICEBOOK'=>'Tarifa:',
'LBL_PRICEBOOK_INFORMATION'=>'Información Tarifa:',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción:',
'LBL_PRICING_INFORMATION'=>'Información Precios:',
'LBL_LIST_FORM_TITLE'=>'Lista Servicios',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Lista Tarifas',
'LBL_LIST_CATEGORY'=>'Categoría Servicio',
'LBL_CATEGORY'=>'Categoría Servicio:',
'LBL_SERVICE_ACTIVE'=>'Servicio Activo',
'LBL_SERVICE_COMMISSION_RATE'=>'Comisión',
'LBL_SERVICE_QTY_PER_UNIT'=>'Unidades',
'LBL_SERVICE_UNIT_PRICE'=>'Precio unitario',
'LBL_PB_LIST_PRICE'=>'Precio lista',
'LBL_SERVICE_DESCRIPTION'=>'Descripción',
'LBL_NEW_FORM_TITLE'=>'Nuevo Servicio',
'LBL_SERVICE_INFORMATION'=>'Información Servicio',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción',

'LBL_SERVICE'=>'Servicio',
'LBL_NEW_SERVICE'=>'Nuevo Servicio',
'LBL_COLON'=>':',

'LBL_DESCRIPTION'=>'Descripción',

'LBL_NEW_CALL'=>'Nueva llamada',
'LBL_CALL_TITLE'=>'Llamadas',

'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',

'LBL_SERVICECATEGORY'=>'Categoría Servicio',
'Service Category'=>'Categoría Servicio',
'LBL_SUPPORT_START_DATE'=>'Fecha inicio soporte',
'LBL_SUPPORT_EXPIRY_DATE'=>'Fecha fin soporte',

'Commission Rate'=>'Comisión',
'Unit Price'=>'Precio unitario',
'Price'=>'Precio',
'No of Units' => 'Número unidades',
'Service No' => 'Número Servicio',
'Service Active' => 'Servicio Activo',
'Owner' => 'Propietario',
'Support Start Date'=>'Fecha inicio soporte',
'Support Expiry Date'=>'Fecha fin soporte',
'Sales Start Date'=>'Fecha inicio venta',
'Sales End Date'=>'Fecha fin venta',
'Created Time'=>'Fecha creación',
'Modified Time'=>'Fecha modificación',
'Related To'=>'Relacionado con',
'Usage Unit'=>'Unidades de consumo',
'Currency'=>'Moneda',
'Tax Class'=>'Tipo impuesto',

//Mapping for Name
'Name'=>'Nombre',
'Company Name'=>'Nombre empresa',
'Phone'=>'Teléfono',
'Email'=>'Email',
'Website'=>'Página Web',
'Category'=>'Categoría',
'Street'=>'Dirección',
'City'=>'Población',
'State'=>'Provincia',
'Postal Code'=>'Código Postal',
'Country'=>'País',
'Description'=>'Descripción',
'Po Box'=>'Apdo. Correos',

//Mapping for price book
'Price Book Name'=>'Nombre Tarifa',
'Service Name'=>'Nombre Servicio',
'Active'=>'Activo',

'LBL_ALL'=>'Todos',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'Buscar Tarifa',
'LBL_PRICEBOOK_TITLE'=>'Tarifas',
'LBL_SERVICES_TITLE'=>'Servicios',
'LBL_COMPANY_NAME'=>'Nombre empresa',
'LBL_CATEGORY_TITLE'=>'Categoría',
'LBL_ACTIVE_TITLE'=>'Activo',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Añadir a Tarifas [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Añadir a Tarifas',
'LBL_ADD_SERVICE_PRICEBOOKS'=>'Añadir Servicio a Tarifas',
'LBL_ADD_SERVICES_PRICEBOOK'=>'Añadir Servicios a Tarifa',
'LBL_SERVICE_PRICES'=>'Precios Servicio',
'Services'=>'Servicios',

// Picklist
'--None--' => '--Ninguno--',
'Installation' => 'Instalación',
'Migration' => 'Migración',
'Customization' => 'Personalización',
'Training' => 'Formación',
'Hours'=>'Horas',
'Days'=>'Días',
'Incidents'=>'Incidentes',

'LBL_NO_TAXES_ASSOCIATED'=>'No hay impuestos asociados a este servicio',
'Services ID'=>'Id Servicio',
);

?>
